@@ -28,7 +28,7 @@ int  dayevents(struct icaltimetype dt, GtkWidget *table);
 
 void deleteCalObjs();
 void addCalObj(struct icaltimetype start, struct icaltimetype end,
-	       int type, char *text, icalcomponent * d);
+	       int type, const char *text, icalcomponent * d);
 int  getDayType(struct icaltimetype dt);
 int  calcDayType(struct icaltimetype dt);
 char* read_stream(char *s, size_t size, void *d);
